@@ -63,6 +63,14 @@ pub enum Sub {
         #[structopt(long)]
         query: String,
     },
+
+    #[structopt(name = "package", about = "packages util")]
+    #[structopt(setting(clap::AppSettings::ColoredHelp))]
+    /// Packages utils.
+    Package {
+        #[structopt(subcommand)]
+        sub: Package,
+    },
 }
 
 #[derive(StructOpt)]
@@ -118,3 +126,11 @@ pub enum Tracking {
         whois: bool,
     },
 }
+
+#[derive(StructOpt)]
+pub enum Package {
+    #[structopt(name = "update", about = "Update packages")]
+    #[structopt(setting(clap::AppSettings::ColoredHelp))]
+    /// Update packages.
+    Update,
+}
